<template>
  <div class="p-2">
    <el-card shadow="never">
      <template #header>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['qms:sensorResult:add']">新增</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate()" v-hasPermi="['qms:sensorResult:edit']">修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete()" v-hasPermi="['qms:sensorResult:remove']">删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['qms:sensorResult:export']">导出</el-button>
          </el-col>
          <right-toolbar v-model:showSearch="showSearch" :columns="columns" @queryTable="getList"></right-toolbar>
        </el-row>
      </template>

      <el-table
        v-loading="loading"
        :data="sensorResultList"
        :row-key="(row) => `${row.batchCode}-${row.testNum}`"

        stripe
        highlight-current-row
        indent="50"
        @selection-change="handleSelectionChange"
      >
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column label="批次号" align="center" prop="batchCode" v-if="columns[0].visible" />
        <el-table-column label="测试序号" align="center" prop="testNum" v-if="columns[1].visible" />
        <el-table-column label="判定结果" align="center" prop="judgeResult" v-if="columns[2].visible" />
        <el-table-column label="总测试项数" align="center" prop="totalCount" v-if="columns[3].visible" />
        <el-table-column label="OK项数" align="center" prop="okCount" v-if="columns[4].visible" />
        <el-table-column label="NG项数" align="center" prop="ngCount" v-if="columns[5].visible" />
        <el-table-column label="创建时间" align="center" prop="createTime" v-if="columns[6].visible" />
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-tooltip content="明细" placement="top">
              <el-button link type="primary" icon="Document" @click="handleDetail(scope.row)"></el-button>
            </el-tooltip>
            <el-tooltip content="修改" placement="top">
              <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['qms:sensorResult:edit']"></el-button>
            </el-tooltip>
            <el-tooltip content="删除" placement="top">
              <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['qms:sensorResult:remove']"></el-button>
            </el-tooltip>
          </template>
        </el-table-column>
      </el-table>

      <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />
    </el-card>
    <!-- 添加或修改批次明细对话框 -->
    <el-dialog :title="dialog.title" v-model="dialog.visible" width="500px" append-to-body>
      <el-form ref="sensorResultFormRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="判定结果" prop="judgeResult">
          <el-input v-model="form.judgeResult" placeholder="请输入判定结果" />
        </el-form-item>
        <el-form-item label="总测试项数" prop="totalCount">
          <el-input v-model="form.totalCount" placeholder="请输入总测试项数" />
        </el-form-item>
        <el-form-item label="OK项数" prop="okCount">
          <el-input v-model="form.okCount" placeholder="请输入OK项数" />
        </el-form-item>
        <el-form-item label="NG项数" prop="ngCount">
          <el-input v-model="form.ngCount" placeholder="请输入NG项数" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="SensorResult" lang="ts">
import { listSensorResult, getSensorResult, delSensorResult, addSensorResult, updateSensorResult } from '@/api/qms/sensorResult';
import { SensorResultVO, SensorResultQuery, SensorResultForm } from '@/api/qms/sensorResult/types';
import { ref, reactive, watch, onMounted } from 'vue';

const { proxy } = getCurrentInstance() as ComponentInternalInstance;

const sensorResultList = ref<SensorResultVO[]>([]);
const buttonLoading = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref<Array<string | number>>([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);

const queryFormRef = ref<ElFormInstance>();
const sensorResultFormRef = ref<ElFormInstance>();

const dialog = reactive<DialogOption>({
  visible: false,
  title: ''
});

const initFormData: SensorResultForm = {
  batchCode: undefined,
  testNum: undefined,
  judgeResult: undefined,
  totalCount: undefined,
  okCount: undefined,
  ngCount: undefined,
  createTime: undefined, // 添加 createTime 字段
}
const data = reactive<PageData<SensorResultForm, SensorResultQuery>>({
  form: {...initFormData},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    judgeResult: undefined,
    totalCount: undefined,
    okCount: undefined,
    ngCount: undefined,
    params: {
    }
  },
  rules: {
    batchCode: [
      { required: true, message: "批次号不能为空", trigger: "blur" }
    ],
    testNum: [
      { required: true, message: "测试序号不能为空", trigger: "blur" }
    ],
    judgeResult: [
      { required: true, message: "判定结果不能为空", trigger: "blur" }
    ],
    totalCount: [
      { required: true, message: "总测试项数不能为空", trigger: "blur" }
    ],
    okCount: [
      { required: true, message: "OK项数不能为空", trigger: "blur" }
    ],
    ngCount: [
      { required: true, message: "NG项数不能为空", trigger: "blur" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

// 添加 columns 数组
const columns = ref<FieldOption[]>([
  { key: 0, label: '批次号', align: 'center', visible: true },
  { key: 1, label: '测试序号', align: 'center', visible: true },
  { key: 2, label: '判定结果', align: 'center', visible: true },
  { key: 3, label: '总测试项数', align: 'center', visible: true },
  { key: 4, label: 'OK项数', align: 'center', visible: true },
  { key: 5, label: 'NG项数', align: 'center', visible: true },
  { key: 6, label: '创建时间', align: 'center', visible: true },
]);

/** 查询批次明细列表 */
const getList = async () => {
  loading.value = true;
  queryParams.value.batchCode = proxy.$route.query.batchCode;
  const res = await listSensorResult(queryParams.value);
  sensorResultList.value = res.rows;
  total.value = res.total;
  loading.value = false;
}

/** 取消按钮 */
const cancel = () => {
  reset();
  dialog.visible = false;
}

/** 表单重置 */
const reset = () => {
  form.value = {...initFormData};
  sensorResultFormRef.value?.resetFields();
}

/** 搜索按钮操作 */
const handleQuery = () => {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value?.resetFields();
  handleQuery();
}

/** 多选框选中数据 */
const handleSelectionChange = (selection: SensorResultVO[]) => {
  ids.value = selection.map(item => item.batchCode);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
const handleAdd = () => {
  reset();
  dialog.visible = true;
  dialog.title = "添加批次明细";
}

/** 修改按钮操作 */
const handleUpdate = async (row?: SensorResultVO) => {
  reset();
  const _batchCode = row?.batchCode || ids.value[0]
  const res = await getSensorResult(_batchCode);
  Object.assign(form.value, res.data);
  dialog.visible = true;
  dialog.title = "修改批次明细";
}

/** 提交按钮 */
const submitForm = () => {
  sensorResultFormRef.value?.validate(async (valid: boolean) => {
    if (valid) {
      buttonLoading.value = true;
      if (form.value.batchCode) {
        await updateSensorResult(form.value).finally(() =>  buttonLoading.value = false);
      } else {
        await addSensorResult(form.value).finally(() =>  buttonLoading.value = false);
      }
      proxy?.$modal.msgSuccess("操作成功");
      dialog.visible = false;
      await getList();
    }
  });
}

/** 删除按钮操作 */
const handleDelete = async (row?: SensorResultVO) => {
  const _batchCodes = row?.batchCode || ids.value;
  await proxy?.$modal.confirm('是否确认删除批次明细编号为"' + _batchCodes + '"的数据项？').finally(() => loading.value = false);
  await delSensorResult(_batchCodes);
  proxy?.$modal.msgSuccess("删除成功");
  await getList();
}

/** 导出按钮操作 */
const handleExport = () => {
  proxy?.download('qms/sensorResult/export', {
    ...queryParams.value
  }, `sensorResult_${new Date().getTime()}.xlsx`)
}

const handleDetail = (sensor) => {
  console.log("sensor", sensor)
  if (!sensor.retestNum) {
    proxy.$router.push({ path: 'testResult', query: {batchCode: sensor.batchCode, testNum: sensor.testNum} });
  } else {
    proxy.$router.push({ path: 'retestResult', query: {batchCode: sensor.batchCode.split("-")[0], testNum: sensor.testNum, retestNum: sensor.retestNum} });
  }

}

watch(()=>proxy.$route.query.batchCode,(batchCode)=>{
  console.log("batchCode", batchCode)
  if(batchCode) {
    getList();
  }
})

onMounted(() => {
  getList();
});
</script>
